Overview of Solar Sails
=======================

..  start-badges

|buildstatus| |docs|

.. |buildstatus| image:: https://img.shields.io/travis/metrasynth/solar-sails.svg?style=flat
    :alt: build status
    :scale: 100%
    :target: https://travis-ci.org/metrasynth/solar-sails

.. |docs| image:: https://readthedocs.org/projects/solar-sails/badge/?version=latest
    :alt: Documentation Status
    :scale: 100%
    :target: https://solar-sails.readthedocs.io/en/latest/?badge=latest

..  end-badges

Part of the Metrasynth_ project.

.. _Metrasynth: https://metrasynth.github.io/


Purpose
-------

"SunVox Augmentation and Interactive Live-coding System"

Solar Sails is a cross-platform app that augments the SunVox_
modular music studio.

..  _SunVox:
    http://warmplace.ru/soft/sunvox/

It combines `Radiant Voices`_, `Solar Flares`_, and sunvox-dll-python_
into a downloadable app that provides a workspace to make use of those tools.

..  _Radiant Voices:
    https://radiant-voices.readthedocs.io/

..  _Solar Flares:
    https://solar-flares.readthedocs.io/

..  _sunvox-dll-python:
    https://sunvox-dll-python.readthedocs.io/


Requirements
------------

- Python 3.5

- OS supported by PyQt5_ and sunvox-dll-python_.

..  _PyQt5:
    https://pypi.org/project/PyQt5/
